summaryrefslogtreecommitdiff
path: root/src/mesa/main/texcompress.c
diff options
context:
space:
mode:
authorDaniel Borca <dborca@users.sourceforge.net>2003-11-03 12:13:23 +0000
committerDaniel Borca <dborca@users.sourceforge.net>2003-11-03 12:13:23 +0000
commitef387549bda21c6338817c83ecfb248dc92cd001 (patch)
tree7ad26f7cde76c7490ed631b413583aee6a44567e /src/mesa/main/texcompress.c
parent313e12e05843dadb12a3a53d2dd161478c9b3202 (diff)
small fixes wrt texture handling
Diffstat (limited to 'src/mesa/main/texcompress.c')
-rw-r--r--src/mesa/main/texcompress.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/mesa/main/texcompress.c b/src/mesa/main/texcompress.c
index 1b9daac1e6b..3e06275c930 100644
--- a/src/mesa/main/texcompress.c
+++ b/src/mesa/main/texcompress.c
@@ -103,10 +103,10 @@ _mesa_compressed_texture_size( GLcontext *ctx,
switch (format) {
case GL_COMPRESSED_RGB_FXT1_3DFX:
case GL_COMPRESSED_RGBA_FXT1_3DFX:
- /* round up to multiple of 4 */
+ /* round up to multiples of 8, 4 */
size = ((width + 7) / 8) * ((height + 3) / 4) * 16;
/* Textures smaller than 4x4 will effectively be made into 4x4 and
* take 8 bytes.
*/
if (size < 16)
size = 16;
@@ -161,7 +161,7 @@ _mesa_compressed_row_stride(GLenum format, GLsizei width)
switch (format) {
case GL_COMPRESSED_RGB_FXT1_3DFX:
case GL_COMPRESSED_RGBA_FXT1_3DFX:
- bytesPerTile = 8;
+ bytesPerTile = 16;
break;
case GL_COMPRESSED_RGB_S3TC_DXT1_EXT:
case GL_COMPRESSED_RGBA_S3TC_DXT1_EXT:
@@ -208,7 +208,7 @@ _mesa_compressed_image_address(GLint col, GLint row, GLint img,
switch (format) {
case GL_COMPRESSED_RGB_FXT1_3DFX:
case GL_COMPRESSED_RGBA_FXT1_3DFX:
- bytesPerTile = 8;
+ bytesPerTile = 16;
break;
case GL_COMPRESSED_RGB_S3TC_DXT1_EXT:
case GL_COMPRESSED_RGBA_S3TC_DXT1_EXT:
@@ -103,10 +103,10 @@ _mesa_compressed_texture_size( GLcontext *ctx,
size = ((width + 7) / 8) * ((height + 3) / 4) * 16;
- /* Textures smaller than 4x4 will effectively be made into 4x4 and
- * take 8 bytes.
+ /* Textures smaller than 8x4 will effectively be made into 8x4 and
+ * take 16 bytes.
*/
if (size < 16)